import QtQuick 1.1
import com.nokia.meego 1.0
import QtWebKit 1.0

Page {
    id: infoPage

    orientationLock: PageOrientation.LockPortrait

    tools: ToolBarLayout {
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                visible: true
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-search"
            onClicked: pageStack.push(Qt.resolvedUrl("SearchStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent==undefined ? undefined : parent.right
        }
    }


    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#247800"
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height

            Label {
                id:headerName
                text:"Información General"
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Label {
                id:headerSubject
                text:"Registración y uso del servicio"
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }


    Flickable  {
        id:flickable
        width: parent.width
        height: parent.height - 88
        anchors.bottom: parent.bottom
        anchors.top: header.bottom
        anchors.topMargin: 16
        contentHeight: Math.max(parent.height,infoView.height)

        Text {
            id:infoView
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            wrapMode: "WrapAtWordBoundaryOrAnywhere"
            font.pixelSize: 18
            font.family: "Nokia Pure Text"
            onLinkActivated: Qt.openUrlExternally('http://mejorenbici.buenosaires.gob.ar')
            text: "
                    <h2>Inscripción</h2>
                    <p>
                        La Ciudad de Buenos Aires  ya tiene su  Sistema de Transporte Público de Bicicletas.
                        Buscá una bici en tu estación más próxima y empezá a disfrutar de un medio de transporte
                        rápido, ecológico y saludable.
                    </p>

                    <p>
                        Este sistema está aplicándose con gran éxito en más de 200 ciudades del mundo.
                    </p>

                    <p>
                        Podés registrarte en cualquier estación. Para ello presentá tu documento de identidad
                        (DNI, Cédula de identidad o Pasaporte) y una factura de un servicio a tu nombre
                        (en caso de no tenerla, de un servicio del domicilio de tu documento) o un certificado
                        de domicilio de Policía Federal Argentina, y fotocopia de ambos. El servicio tiene que
                        tener como máximo 2 meses de antigüedad y no debe tener deuda. Una vez registrado,
                        con tu número de PIN retirás tu bici. Podrás utilizarla con un límite de 1 hora.
                        Luego deberás devolverla en la estación más próxima a tu destino.
                    <p>
                    <p>
                        El servicio es gratuito y funciona de lunes a viernes entre las 8 y las 20 h y los sábados
                        de 9 a 15 h. con excepción de la estación CMD que funciona de lunes a viernes de 10 a 18 h.
                        El servicio no funciona los días feriados.
                    <p>
                    <h3>¿Cómo funciona el servicio?</h3>
                    <ol>
                        <li style='margin:2px 0;'>
                            Presentá tu número de documento al personal de Mejor en bici en cualquier estación.
                        </li>
                        <li style='margin:2px 0;'>
                            Se compara la foto del usuario y se registra la transacción ingresando tu número PIN de usuario.
                        </li>
                        <li style='margin:2px 0;'>
                            Retirás la bici y el casco.
                        </li>
                        <li style='margin:2px 0;'>
                            Siempre priorizá circular por las ciclovías protegidas. Tenés un máximo de 1 hora de uso por cada viaje.
                        </li>
                        <li style='margin:2px 0;'>
                            Devolvé la bici al personal de Mejor en Bici en la estación más próxima a tu destino.
                            <ul>
                                <li style='margin:2px 0;'>
                                    Una vez registrado, podés utilizar el servicio las veces que quieras de lunes a viernes entre
                                    las 8 y las 20 h y los sábados de 9 a 15 h con un límite de una hora.
                                </li>
                                <li style='margin:2px 0;'>
                                    Las bicicletas tienen un color y diseño distintivo. Para que el sistema siga funcionando
                                    necesitamos de tu colaboración, cuidá la bici y devolvela en el tiempo estipulado.
                                </li>
                            </ul>
                        </li>
                    </ol>
                    <h3>Mas información: </h3>
                    <p><a href='http://mejorenbici.buenosaires.gob.ar'>http://mejorenbici.buenosaires.gob.ar</a></p>
                    <p><strong>Fuente: </strong>Gobierno de la Ciudad de Buenos Aires</p><br>"
        }
    }

    ScrollDecorator {
        flickableItem: flickable
    }
}
