import QtQuick 1.1
import com.nokia.meego 1.0
import QtWebKit 1.0
import QtMobility.location 1.2

Page {
    id: stationsDetailsPage

    orientationLock: PageOrientation.LockPortrait

    tools: ToolBarLayout {
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                visible: true
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-search"
            onClicked: pageStack.push(Qt.resolvedUrl("SearchStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent===undefined ? undefined : parent.right
        }
    }

    Coordinate { id: defaultMapCenter; latitude: mapLat; longitude: mapLong}

    BusyIndicator {
        id: indicator1
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        running: true
        z:100
        scale:1
    }

    Component.onCompleted: {
        indicator1.visible = false
        indicator1.running = false
    }
    ListModel {
        id:stationModel
        Component.onCompleted: {
            window.getManager().generateStationModel(stationModel, station_id);

            headerName.text = stationModel.get(0).name
            headerSubject.text = stationModel.get(0).address

            mapLat = stationModel.get(0).mapLat
            mapLong = stationModel.get(0).mapLong
        }
    }

    ListModel {
        id:stationsModel
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#6b207f"

        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height

            Label {
                id:headerName
                text:""
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Label {
                id:headerSubject
                text:""
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }

    Map {
        id: map
        mapType: mapOptions.selectedIndex >= 0 ? mapOptions.model.get(mapOptions.selectedIndex).value : "TransitMap"
        anchors.top: header.bottom
        anchors.topMargin: 0
        anchors.right: parent.right
        anchors.rightMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 0
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        plugin : Plugin {
            name : "nokia";
            //            parameters: [
            //                PluginParameter { name: "app_id"; value: "vCZKLhbqnhKrH29MJid0" },
            //                PluginParameter { name: "token"; value: "zpDSWFBWtWBGHJNmIMMxKQ%3D%3D" }
            //            ]
        }
        size.width: parent.width
        size.height: parent.height - header.height
        zoomLevel: 17
        center: defaultMapCenter

        MapImage {
            id : pin
            coordinate: defaultMapCenter
            source:"images/pin.png"
        }
    }

    PinchArea {
        id: pincharea
        z:9
        property double __oldZoom

        anchors.fill: parent

        function calcZoomDelta(zoom, percent) {
            return zoom + Math.log(percent)/Math.log(2)
        }

        onPinchStarted: {
            __oldZoom = map.zoomLevel
        }

        onPinchUpdated: {
            map.zoomLevel = calcZoomDelta(__oldZoom, pinch.scale)
        }

        onPinchFinished: {
            map.zoomLevel = calcZoomDelta(__oldZoom, pinch.scale)
        }
    }

    MouseArea {
        id: mousearea
        z:9
        property bool __isPanning: false
        property int __lastX: -1
        property int __lastY: -1

        anchors.fill : parent

        onPressed: {
            __isPanning = true
            __lastX = mouse.x
            __lastY = mouse.y
        }

        onReleased: {
            __isPanning = false
        }

        onPositionChanged: {
            if (__isPanning) {
                var dx = mouse.x - __lastX
                var dy = mouse.y - __lastY
                map.pan(-dx, -dy)
                __lastX = mouse.x
                __lastY = mouse.y
            }
        }

        onCanceled: {
            __isPanning = false;
        }
    }

    Image {
        id:mapSelector
        z:10
        source: "images/map_selector.png"
        width:48
        height:48
        anchors.right: parent.right
        anchors.rightMargin: 20
        anchors.top: header.bottom
        anchors.topMargin: 20
        Image {
            source:"images/toolbar-settings.png"
            width:30
            height: 30
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
        }

        MouseArea {
            id: mouseArea
            anchors.fill: parent
            onClicked: {
                mapOptions.open();
            }
        }
    }

    SelectionDialog {
        id: mapOptions
        titleText: "Opciones de mapa"

        model: ListModel {
            ListElement {
                name: "Mapa"
                value:"TransitMap"
            }
            ListElement {
                name: "Satélite"
                value:"HybridMap"
            }
            ListElement {
                name: "Terreno"
                value:"TerrainMap"
            }
        }

    }
}
